@@ -24,23 +24,26 @@
 
 #include "kmplot.h"
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <kedittoolbar.h>
-#include <kshortcutsdialog.h>
-#include <kfiledialog.h>
-#include <klibloader.h>
-#include <kmessagebox.h>
-#include <kmplotprogress.h>
-#include <kstatusbar.h>
-#include <kstandardaction.h>
-#include <kurl.h>
-#include <kactioncollection.h>
-#include "maindlg.h"
-#include <ktoolinvocation.h>
-#include <ktogglefullscreenaction.h>
+#include <QFileDialog>
+#include <QLabel>
+#include <QStatusBar>
+#include <QUrl>
 
+#include <KActionCollection>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KPluginLoader>
+#include <KShortcutsDialog>
+#include <KStandardAction>
+#include <KToggleFullScreenAction>
+#include <KToolInvocation>
+
+#include "maindlg.h"
+#include <kmplotprogress.h>
 #include "kmplotadaptor.h"
+#include "view.h"
 
 static QUrl urlFromArg(const QString &arg)
 {
@@ -119,7 +122,7 @@ KmPlot::KmPlot( const QCommandLineParser& parser )
 				openFileInNewWindow( url );
 		}
 		if (exit)
-			deleteLater(); // couln't open the file, and therefore exit
+			deleteLater(); // couldn't open the file, and therefore exit
 		first = false;
 	}
 
@@ -157,7 +160,7 @@ bool KmPlot::load(const QUrl& url)
 	m_part->openUrl( url );
 	if (m_part->url().isEmpty())
 		return false;
-	setCaption(url.toDisplayString());
+	setWindowTitle(url.toDisplayString());
 	return true;
 }
 
@@ -196,9 +199,7 @@ void KmPlot::fileOpen()
 	// this slot is called whenever the File->Open menu is selected,
 	// the Open shortcut is pressed (usually CTRL+O) or the Open toolbar
 	// button is clicked
-	QUrl const url = KFileDialog::getOpenUrl( QUrl::fromLocalFile(QDir::currentPath()),
-	                 i18n( "*.fkt|KmPlot Files (*.fkt)\n*|All Files" ),
-			 this, i18n( "Open" ) );
+	QUrl const url = QFileDialog::getOpenFileUrl(this, i18n( "Open" ), QUrl::fromLocalFile(QDir::currentPath()), i18n( "KmPlot Files (*.fkt);;All Files (*)"));
 
 	if ( !url.isEmpty())
 	{
@@ -247,22 +248,31 @@ bool KmPlot::queryClose()
 
 void KmPlot::setStatusBarText(const QString &text, int id)
 {
-	static_cast<KStatusBar *>(statusBar())->changeItem(text,id);
+	static_cast<QLabel *>(statusBarLabels.at(id))->setText(text);
 }
 
 
 void KmPlot::setupStatusBar()
 {
-	KStatusBar *statusBar = new KStatusBar(this);
+	QStatusBar *statusBar = new QStatusBar(this);
 	setStatusBar(statusBar);
 
-	statusBar->insertFixedItem( "1234567890123456", 1 );
-	statusBar->insertFixedItem( "1234567890123456", 2 );
-	statusBar->insertItem( "", 3, 3 );
-	statusBar->insertItem( "", 4 );
-	statusBar->changeItem( "", 1 );
-	statusBar->changeItem( "", 2 );
-	statusBar->setItemAlignment( 3, Qt::AlignLeft );
+	for (int i = 0; i < View::SectionCount; ++i)
+	{
+		QLabel *label = new QLabel (statusBar);
+		label->setFixedHeight (label->fontMetrics ().height () + 2);
+		/// Labels for coordinates should be of fixed width 16 chars to be the same as for good old KmPlot
+		if ( i < 2) {
+			label->setFixedWidth ( label->fontMetrics ().width (QLatin1Char ('8')) * 16 );
+			label->setAlignment( Qt::AlignCenter );
+		}
+		else {
+			label->setAlignment( Qt::AlignLeft );
+		}
+
+		statusBar->addWidget (label);
+		statusBarLabels.append (label);
+	}
 
 	m_progressBar = new KmPlotProgress( statusBar );
 	m_progressBar->setMaximumHeight( statusBar->height()-10 );
