@@ -32,11 +32,11 @@
 #include "maindlg.h"
 
 // KDE includes
-#include <kinputdialog.h>
 #include <KLocalizedString>
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 #include <QList>
+#include <QDebug>
 
 #include <assert.h>
 #include <cmath>
@@ -151,7 +151,7 @@ double XParser::derivative( int n, Equation * eq, DifferentialState * state, dou
 {
 	if ( n < -1 )
 	{
-		kError() << "Can't handle derivative < -1\n";
+		qCritical() << "Can't handle derivative < -1\n";
 		return 0.0;
 	}
 	
@@ -182,7 +182,7 @@ double XParser::partialDerivative( int n1, int n2, Equation * eq, DifferentialSt
 {
 	if ( n1 < 0 || n2 < 0 )
 	{
-		kError() << "Can't handle derivative < 0\n";
+		qCritical() << "Can't handle derivative < 0\n";
 		return 0.0;
 	}
 	
@@ -268,11 +268,11 @@ void XParser::fixFunctionName( QString &str, Equation::Type const type, int cons
 			str = str.mid(p1,str.length()-1);
 			QString function_name;
 			if ( type == Equation::ParametricX )
-				function_name = "x";
+				function_name = 'x';
 			else if ( type == Equation::ParametricY )
-				function_name = "y";
+				function_name = 'y';
 			else
-				function_name = "f";
+				function_name = 'f';
 			function_name = findFunctionName( function_name, id );
 			str.prepend( function_name );
 			return;
@@ -308,7 +308,7 @@ double XParser::differential( Equation * eq, DifferentialState * state, double x
 	
 	if ( eq->order() < 1 )
 	{
-		kWarning() << "Zero order!\n";
+		qWarning() << "Zero order!\n";
 		return 0;
 	}
 	
